@@ -19,9 +19,8 @@
 """
 This module contains the tables.
 """
-import webbrowser
-import shutil
 import os
+import shutil
 import logging
 from functools import partial
 
@@ -40,7 +39,7 @@ from PyQt5.QtWidgets import (
 import get_data
 import creator
 from dialogs import ConsoleDialog, ProgBarDialog
-from creator import CloningWorker
+from creator import InstallWorker
 from manage_pip import PipManager
 
 
@@ -89,6 +88,7 @@ class VenvTable(BaseTable):
     finished = pyqtSignal()
     text_changed = pyqtSignal(str)
     refresh = pyqtSignal()
+    start_installer = pyqtSignal()
 
 
     def __init__(self, *args, **kwargs):
@@ -113,18 +113,16 @@ class VenvTable(BaseTable):
         self.progress_bar = ProgBarDialog()
         self.console = ConsoleDialog()
         self.thread = QThread(self)
-        self.m_clone_repo_worker = CloningWorker()
+        self.m_install_worker = InstallWorker()
 
         # thread
         self.thread.start()
-        self.m_clone_repo_worker.moveToThread(self.thread)
+        self.m_install_worker.moveToThread(self.thread)
 
-        self.m_clone_repo_worker.started.connect(self.progress_bar.exec_)
-        self.m_clone_repo_worker.finished.connect(self.progress_bar.close)
-        self.m_clone_repo_worker.finished.connect(self.vcs_finish_info)
-
-        self.m_clone_repo_worker.failed.connect(self.progress_bar.close)
-        self.m_clone_repo_worker.failed.connect(self.vcs_abort_info)
+        self.m_install_worker.started.connect(self.console.exec_)
+        self.m_install_worker.text_changed.connect(
+            self.console.update_status
+        )
 
         # perform a proper stop using quit() and wait()
         self.thread.finished.connect(self.thread.quit)
@@ -332,8 +330,8 @@ class VenvTable(BaseTable):
         version = get_data.get_config(cfg_file, "version")
         py_path = get_data.get_config(cfg_file, "py_path")
         msg_txt = (
-            f"This environment requires {version} \n\
-            from {py_path} which is \nnot installed.\n"
+            f"This environment requires {version} \n"
+            f"from {py_path} which is \nnot installed.\n"
         )
 
         if is_installed == "no":
@@ -416,7 +414,7 @@ class VenvTable(BaseTable):
             self.manager.started.connect(self.console.exec_)
 
             # display the updated output
-            self.manager.textChanged.connect(self.console.update_status)
+            self.manager.text_changed.connect(self.console.update_status)
 
             # clear the content on window close
             if self.console.close:
@@ -430,30 +428,13 @@ class VenvTable(BaseTable):
         """
         active_dir = get_data.get_active_dir_str()
         venv = self.get_selected_item()
+        venv_path = os.path.join(active_dir, venv)
 
         if self.has_pip(active_dir, venv):
-            project_name, ok = QInputDialog.getText(
-                self,
-                "Specify project",
-                "Enter a PyPI project name:" + " " * 70
-            )
+            with open(get_data.ACTIVE_VENV, "w") as f:
+                f.write(venv_path)
 
-            if project_name != "":
-                self.console.setWindowTitle(f"Installing {project_name}")
-                logger.debug("Installing specified project...")
-
-                self.manager = PipManager(active_dir, venv)
-                self.manager.run_pip(
-                    creator.cmds[0], [creator.opts[0], f"'{project_name}'"]
-                )
-                self.manager.started.connect(self.console.exec_)
-
-                # display the updated output
-                self.manager.textChanged.connect(self.console.update_status)
-
-                # clear the content on window close
-                if self.console.close:
-                    self.console.console_window.clear()
+            self.start_installer.emit()
 
 
     def install_requires(self, event):
@@ -463,6 +444,7 @@ class VenvTable(BaseTable):
         """
         active_dir = get_data.get_active_dir_str()
         venv = self.get_selected_item()
+        venv_bin = os.path.join(active_dir, venv, "bin", "python")
 
         if self.has_pip(active_dir, venv):
             file_name = QFileDialog.getOpenFileName(
@@ -473,17 +455,15 @@ class VenvTable(BaseTable):
 
             if file_path != "":
                 creator.fix_requirements(file_path)
-                self.console.setWindowTitle("Installing from requirements")
                 logger.debug("Installing from requirements...")
-
-                self.manager = PipManager(active_dir, venv)
-                self.manager.run_pip(
-                    creator.cmds[0], [creator.opts[1], f"'{file_path}'"]
+                cmd = (
+                    f"{venv_bin} -m pip {creator.cmds[0]} {creator.opts[1]} {file_path}"
                 )
-                self.manager.started.connect(self.console.exec_)
-
-                # display the updated output
-                self.manager.textChanged.connect(self.console.update_status)
+                self.console.setWindowTitle(
+                    "Installing from requirements file"
+                )
+                wrapper = partial(self.m_install_worker.run_process, cmd)
+                QTimer.singleShot(0, wrapper)
 
                 # clear the content on window close
                 if self.console.close:
@@ -515,7 +495,7 @@ class VenvTable(BaseTable):
                     self.manager.started.connect(self.console.exec_)
 
                     # display the updated output
-                    self.manager.textChanged.connect(self.console.update_status)
+                    self.manager.text_changed.connect(self.console.update_status)
 
                     # clear the content on window close
                     if self.console.close:
@@ -523,7 +503,7 @@ class VenvTable(BaseTable):
 
                 else:
                     msg_txt = (
-                        "Filesystem is read-only.\n\n"
+                        "Filesystem not writable.\n\n"
                         "Unable to create the '.egg-info'      \n"
                         "folder inside the project directory.      \n\n"
                     )
@@ -553,36 +533,15 @@ class VenvTable(BaseTable):
                 cmd = (
                     f"{venv_bin} -m pip {creator.cmds[0]} {formatted_project_url}"
                 )
-                self.progress_bar.setWindowTitle(f"Installing {self.vcs_project_name}")
-                self.progress_bar.status_label.setText(
-                    "Installing from repository...  (this can take a moment)"
-                )
-
-                wrapper = partial(
-                    self.m_clone_repo_worker.run_process,
-                    cmd
+                self.console.setWindowTitle(
+                    f"Installing {self.vcs_project_name}"
                 )
+                wrapper = partial(self.m_install_worker.run_process, cmd)
                 QTimer.singleShot(0, wrapper)
 
-
-    def vcs_finish_info(self):
-        """Info message if successfully installed from repository.
-        """
-        msg_txt = (
-            "Successfully installed:           \n"
-            f"{self.vcs_project_name}\n"
-        )
-        QMessageBox.information(self, "Done", msg_txt)
-
-
-    def vcs_abort_info(self):
-        """Error message if installing from repository failed.
-        """
-        msg_txt = (
-            "Unable to install from\n"
-            f"{self.vcs_project_url}          \n"
-        )
-        QMessageBox.warning(self, "Abort", msg_txt)
+                # clear the content on window close
+                if self.console.close:
+                    self.console.console_window.clear()
 
 
     def save_requires(self, event):
@@ -633,7 +592,7 @@ class VenvTable(BaseTable):
             self.manager.started.connect(self.console.exec_)
 
             # display the updated output
-            self.manager.textChanged.connect(self.console.update_status)
+            self.manager.text_changed.connect(self.console.update_status)
 
             # clear the content on window close
             if self.console.close:
@@ -781,60 +740,6 @@ class VenvTable(BaseTable):
 
 
 
-class ResultsTable(BaseTable):
-    """Contains the results from PyPI.
-    """
-    context_triggered = pyqtSignal()
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
-        self.info_icon = QIcon(
-            self.style().standardIcon(QStyle.SP_FileDialogInfoView)
-        )
-
-    def contextMenuEvent(self, event):
-        context_menu = QMenu(self)
-
-        # pop up only if clicking on a row
-        if self.indexAt(event.pos()).isValid():
-            context_menu.popup(QCursor.pos())
-
-        install_action = QAction(
-            QIcon.fromTheme("software-install"),
-            "&Install module",
-            self,
-            statusTip="Install module"
-        )
-        context_menu.addAction(install_action)
-        # connect to install_package() in InstallPackages() in wizard
-        install_action.triggered.connect(
-            lambda: self.context_triggered.emit()
-        )
-
-        open_pypi_action = QAction(
-            self.info_icon,
-            "&Open on PyPI",
-            self,
-            statusTip="Open on Python Package Index"
-        )
-        context_menu.addAction(open_pypi_action)
-        open_pypi_action.triggered.connect(
-            lambda: self.open_on_pypi(event)
-        )
-
-
-    def open_on_pypi(self, event):
-        """
-        Open pypi.org and show the project description
-        of the selected package.
-        """
-        url = "https://pypi.org/project"
-        package = self.get_selected_item()
-        webbrowser.open("/".join([url, package, "#description"]))
-
-
-
 class InterpreterTable(BaseTable):
     """
     List the Python installs found.
