@@ -58,7 +58,6 @@ from PyQt5.QtWidgets import (
     QAbstractItemView,
     QPushButton,
     QMessageBox,
-    QHeaderView,
     QDesktopWidget
 )
 
@@ -66,7 +65,7 @@ import venvipy_rc  # pylint: disable=unused-import
 import get_data
 import creator
 from dialogs import ProgBarDialog, ConsoleDialog
-from tables import ResultsTable
+from pkg_installer import ResultsTable
 from creator import CreationWorker
 from manage_pip import PipManager
 
@@ -205,7 +204,9 @@ class BasicSettings(QWizardPage):
         self.m_install_venv_worker.updating_pip.connect(
             lambda: logger.debug("Updating pip...")
         )
-        self.m_install_venv_worker.installing_wheel.connect(self.install_wheel_msg)
+        self.m_install_venv_worker.installing_wheel.connect(
+            self.install_wheel_msg
+        )
         self.m_install_venv_worker.installing_wheel.connect(
             lambda: logger.debug("Installing wheel...")
         )
@@ -429,7 +430,7 @@ class BasicSettings(QWizardPage):
         self.requirements_line.setText(file_name[0])
 
 
-    def pip_enabled(self, state):
+    def pip_enabled(self):
         """
         Enable or disable input line for requirements
         and checkbox for installing wheel.
@@ -671,11 +672,7 @@ class InstallPackages(QWizardPage):
         )
 
         # display the updated output
-        self.manager.textChanged.connect(self.console.update_status)
-
-        # show info dialog
-        self.manager.failed.connect(self.console.finish_fail)
-        self.manager.failed.connect(self.console.close)
+        self.manager.text_changed.connect(self.console.update_status)
 
         # clear the contents when closing console
         if self.console.close:
@@ -745,7 +742,7 @@ class InstallPackages(QWizardPage):
             self.manager.run_pip(creator.cmds[0], [creator.opts[0], self.pkg])
 
             # display the updated output
-            self.manager.textChanged.connect(self.console.update_status)
+            self.manager.text_changed.connect(self.console.update_status)
 
             # clear the content when closing console
             if self.console.close:
